package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.dao.*;
import com.community.huiju.exception.WisdomException;
import com.community.huiju.model.*;
import com.community.huiju.service.IToSysRoleService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * 角色业务
 * @author weiximei
 */
@Service("iToSysRoleService")
@Slf4j
public class ToSysRoleServiceImpl implements IToSysRoleService {

    @Autowired
    private ToSysRoleMapper toSysRoleMapper;

    @Autowired
    private ToSysRoleMenuMapper toSysRoleMenuMapper;

    @Autowired
    private ToUserMapper toUserMapper;

    @Override
    public List<ToSysRole> selectRoleByUserId(Integer userId) {

        return toSysRoleMapper.selectRoleByUserId(userId);
    }

    @Override
    public ResponseBean getAll(String parameter) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        Integer pageNum = jsonObject.getInteger("pageNum");
        Integer pageSize = jsonObject.getInteger("pageSize");
        String roleName = jsonObject.getString("roleName").trim();

        Page<ToSysRole> pageInfo = PageHelper.startPage(pageNum, pageSize);
        List<ToSysRole> roleList = toSysRoleMapper.selectAll(roleName);
        roleList.forEach(e -> {
            ToUser createUser = toUserMapper.selectByPrimaryKey(e.getCreateUser());
            ToUser updateUser = toUserMapper.selectByPrimaryKey(e.getUpdateUser());
            e.setCreateUserName(createUser.getUserName());
            e.setUpdateUserName(updateUser.getUserName());
        });

        Map<String, Object> resMap = new HashMap<>();
        resMap.put("list", roleList);
        resMap.put("pageNum", pageInfo.getPageNum());
        resMap.put("pageSize", pageInfo.getPageSize());
        resMap.put("total", pageInfo.getTotal());


        responseBean.addSuccess(resMap);
        return responseBean;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean addRole(String parameter, UserElement userElement) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        String roleName = jsonObject.getString("roleName");
        String description = jsonObject.getString("description");
        Integer [] menuIdArray = jsonObject.getJSONArray("menuArray").toArray(new Integer[] {});

        // 校验这个角色是否存在
        ToSysRole toSysRole = toSysRoleMapper.selectByRoleName(roleName);
        if (toSysRole != null) {
            responseBean.addError("角色已存在!");
            return responseBean;
        }

        ToSysRole createRole = new ToSysRole();
        createRole.setRoleName(roleName);
        createRole.setDescription(description);
        createRole.setUpdateUser(userElement.getId());
        createRole.setCreateUser(userElement.getId());
        createRole.setCreateDate(new Date());
        createRole.setUpdateDate(new Date());
        createRole.setStatus("1");
        int rows = toSysRoleMapper.insertSelective(createRole);

        List<ToSysRoleMenu> roleMenuList = new ArrayList<>();
        for (Integer menuId : menuIdArray) {
            ToSysRoleMenu toSysRoleMenu = new ToSysRoleMenu();
            toSysRoleMenu.setMenuId(menuId);
            toSysRoleMenu.setRoleId(createRole.getId());
            roleMenuList.add(toSysRoleMenu);
        }

        rows = toSysRoleMenuMapper.banchInsert(roleMenuList);
        if (rows <= 0) {
            throw new WisdomException("创建角色失败!");
        }
        responseBean.addSuccess("操作成功!");
        return responseBean;
    }
}
