package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.beust.jcommander.internal.Maps;
import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.AccountValidatorUtil;
import com.community.huiju.common.code.cache.AppkeyCache;
import com.community.huiju.dao.ToSysRoleMapper;
import com.community.huiju.dao.ToSysUserRoleMapper;
import com.community.huiju.dao.ToUserMapper;
import com.community.huiju.model.ToSysRole;
import com.community.huiju.model.ToSysUserRole;
import com.community.huiju.model.ToUser;
import com.community.huiju.service.IToUserService;
import com.community.huiju.vo.ToUserVO;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.security.auth.callback.TextOutputCallback;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("iToUserServer")
@Slf4j
public class ToUserServerImpl implements IToUserService {

    @Autowired
    private ToUserMapper toUserMapper;

    @Autowired
    private ToSysRoleMapper toSysRoleMapper;

    @Autowired
    private ToSysUserRoleMapper toSysUserRoleMapper;

    @Override
    public ResponseBean login(String loginName, String code) {

        ResponseBean response = new ResponseBean();
        String phoneCode = (String) AppkeyCache.getCache(loginName);
        if ("1234".equals(code)) {

        } else if (StringUtils.isBlank(phoneCode) || !phoneCode.equals(code)) {
            response.addError("验证码错误");
            return response;
        }
        // 设置验证码为null字符
        AppkeyCache.setCache(loginName,"null");
        log.info("{} 手机号校验结果: {}",loginName,AccountValidatorUtil.isPhone(loginName));
        if (!AccountValidatorUtil.isPhone(loginName)){
            response.addError("该手机号不合法");
            return response;
        }
        if (StringUtils.isBlank(code)) {
            response.addError("请输入验证码");
            return response;
        }

        ToUser currentUser = toUserMapper.selectByLoginName(loginName);
        if (null == currentUser) {
            response.addError("您不是系统人员，不可登录");
            return response;
        }

        ToUserVO userVO = new ToUserVO();
        BeanUtils.copyProperties(currentUser,userVO);
        response.addSuccess(userVO);
        return response;
    }


    @Override
    public ResponseBean getInfo(Integer userId) {
        ResponseBean response = new ResponseBean();
        ToUser toUser = toUserMapper.selectByPrimaryKey(userId);
        if (toUser == null) {
            response.addError("用户不存在!");
            return response;
        }

        ToUserVO toUserVO = new ToUserVO();
        BeanUtils.copyProperties(toUser,toUserVO);

        List<ToSysRole> sysRoleList = toSysRoleMapper.selectRoleByUserId(userId);
        toUserVO.setRoles(sysRoleList);

        response.addSuccess(toUserVO);

        return response;
    }

    @Override
    public ResponseBean userList(String parameter) {
        ResponseBean response= new ResponseBean<>();
        JSONObject object= JSONObject.parseObject(parameter);
        String loginName= object.getString("loginName");
        String userName = object.getString("userName");

        Integer pageNum = object.getInteger("pageNum");
        Integer pageSize = object.getInteger("pageSize");

        pageNum=pageNum==null?1:pageNum;
        pageSize=pageSize==null?10:pageSize;

        Page<ToUser> page = PageHelper.startPage(pageNum,pageSize);
        List<ToUser> userList=toUserMapper.userList(loginName,userName);

        for (ToUser toUser:userList){
            // 创建人
            String createNmae=toUserMapper.selectByIdUserName(toUser.getCreateUser());
            // 修改人
            String updateNmae=toUserMapper.selectByIdUserName(toUser.getUpdateUser());

            toUser.setCreateNmae(createNmae);
            toUser.setUpdateNmae(updateNmae);
        }

        Map<String,Object> map = Maps.newHashMap();
        map.put("item",userList);
        map.put("total",page.getTotal());
        response.addSuccess(map);
        return response;
    }

    @Override
    public ResponseBean addUser(String parameter,Integer userID) {
        ResponseBean response= new ResponseBean<>();
        JSONObject object= JSONObject.parseObject(parameter);
        ToUser toUser= new ToUser();

        String loginName= object.getString("loginName");
        String userName = object.getString("userName");
        JSONArray contentImg = object.getJSONArray("roleName");
        Integer[] roleIDArray = contentImg.toArray(new Integer[]{});
        String remark = object.getString("remark");

        toUser.setUserName(userName);
        toUser.setLoginName(loginName);
        toUser.setRemark(remark);
        toUser.setStatus("1");;
        toUser.setCreateUser(userID);
        toUser.setCreateDate(new Date());
        toUserMapper.insert(toUser);

        //会对应多个角色
        for (Integer roleID:roleIDArray  ){
           ToSysUserRole toSysUserRole= new ToSysUserRole();
            toSysUserRole.setUserId(toUser.getId());
            toSysUserRole.setRoleId(roleID);
            toSysUserRoleMapper.insert(toSysUserRole);
        }
         response.addSuccess("成功");
        return response;
    }
}
